diff a/test/micro/org/openjdk/bench/vm/compiler/pea/Simple.java b/test/micro/org/openjdk/bench/vm/compiler/pea/Simple.java
--- /dev/null
+++ b/test/micro/org/openjdk/bench/vm/compiler/pea/Simple.java
@@ -0,0 +1,80 @@
+/*
+ * Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.
+ *
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
+ *
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
+ */
+package org.openjdk.bench.vm.compiler.pea;
+
+import org.openjdk.jmh.annotations.Benchmark;
+import org.openjdk.jmh.annotations.BenchmarkMode;
+import org.openjdk.jmh.annotations.CompilerControl;
+import org.openjdk.jmh.annotations.Fork;
+import org.openjdk.jmh.annotations.Measurement;
+import org.openjdk.jmh.annotations.Mode;
+import org.openjdk.jmh.annotations.Param;
+import org.openjdk.jmh.annotations.Scope;
+import org.openjdk.jmh.annotations.State;
+import org.openjdk.jmh.annotations.OutputTimeUnit;
+import org.openjdk.jmh.annotations.Warmup;
+
+import java.util.concurrent.TimeUnit;
+
+@BenchmarkMode(Mode.AverageTime)
+@OutputTimeUnit(TimeUnit.NANOSECONDS)
+@Warmup(iterations = 5, time = 1, timeUnit = TimeUnit.SECONDS)
+@Measurement(iterations = 20, time = 1, timeUnit = TimeUnit.SECONDS)
+@State(Scope.Benchmark)
+@Fork(value = 3)
+public class Simple {
+    @Param({"1", "2", "4", "8"})
+    int odd;
+    private Object _cache;
+
+    void example1(boolean cond) {
+        Object x = new Object();
+        if (cond) {
+            _cache = x;
+        }
+    }
+
+    @Benchmark
+    public void example1() {
+        for (int i = 0; i< 1024; ++i) {
+            boolean cond = (i % odd) == 0;
+            example1(cond);
+        }
+    }
+    @CompilerControl(CompilerControl.Mode.DONT_INLINE)
+    static void escaped_as_argument(Object x) {}
+
+    // Ivanov suggests making this happen first.
+    // we don't need to create JVMState for the cloning Allocate.
+    @Benchmark
+    public void example1_ArgEscape() {
+        for (int i = 0; i< 1024; ++i) {
+            boolean cond = (i % odd) == 0;
+            Object x = new Object();
+
+            if (cond) {
+                escaped_as_argument(x);
+            }
+        }
+    }
+}
